==> klat4-0.5.2.tar.bz2: klat4-0.5.2/klatexecconfig.h <==
/*
    Klat - A LaTeX editor for KDE
    
    Copyright (C) 2002-2004  Jori Liesenborgs (jori@lumumba.luc.ac.be)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef KLATEXECCONFIG_H

#define KLATEXECCONFIG_H

#include <Qt/qstring.h>
#include <list>
#include <kshortcut.h>

class KConfig;

class KlatExecMenuEntry
{
public:
	KlatExecMenuEntry(const QString &section,const QString &menuname,const QString &command,const QString &commandline,const KShortcut &shortcut)	{ sect = section; mname = menuname; cmd = command; cmdline = commandline; cut = shortcut; }
	KlatExecMenuEntry(const KlatExecMenuEntry &src)				{ sect = src.sect; mname = src.mname; cmd = src.cmd; cmdline = src.cmdline; cut = src.cut; }
	QString section() const							{ return sect; }
	QString menuName() const						{ return mname; }
	QString command() const							{ return cmd; }
	QString commandLine() const						{ return cmdline; }
	bool saveFirst() const							{ if (section() == "compile") return true; else return false;}
	KShortcut shortcut() const						{ return cut; }
private:
	QString sect,mname,cmd,cmdline;
	KShortcut cut;
};

class KlatExecConfig
{
public:
	KlatExecConfig();
	~KlatExecConfig();
	void read(KConfig *cfg);
	void write(KConfig *cfg);
	bool gotoFirstEntry();
	bool gotoNextEntry();
	bool gotoEntry(QString str);
	bool gotoEntry(int index);
	QString section();
	QString menuName();
	QString command();
	QString commandLine();
	bool saveFirst();
	KShortcut shortcut();
	KlatExecMenuEntry entry();
	void insertAfterCurrent(const KlatExecMenuEntry &m);
	void deleteCurrent();
	void changeCurrent(const KlatExecMenuEntry &m);
private:
	std::list<KlatExecMenuEntry> execEntries;
	std::list<KlatExecMenuEntry>::iterator it;
};

#endif // KLATEXECCONFIG_H

==> klat4-0.6.1.tar.bz2: klat4-0.6.1/klatexecconfig.h <==
/*
    Klat4 - A LaTeX editor for KDE4

    Copyright (C) 2008  Anna A. Ladilova (ladilova@algebraic.ru)
    Copyright (C) 2002-2004  Jori Liesenborgs (jori@lumumba.luc.ac.be)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef KLATEXECCONFIG_H

#define KLATEXECCONFIG_H

#include <QString>
#include <QList>
#include <KShortcut>

#define SECTCOMP	"compile"
#define SECTCONV	"convert"
#define SECTVIEW	"view"

class KConfig;

class KlatExecMenuEntry
{
public:
	KlatExecMenuEntry(const QString &section,const QString &menuname,const QString &command,const QString &commandline,const KShortcut &shortcut)	{ sect = section; mname = menuname; cmd = command; cmdline = commandline; cut = shortcut; }
	KlatExecMenuEntry(const KlatExecMenuEntry &src)				{ sect = src.sect; mname = src.mname; cmd = src.cmd; cmdline = src.cmdline; cut = src.cut; }
	QString section() const							{ return sect; }
	QString menuName() const						{ return mname; }
	QString command() const							{ return cmd; }
	QString commandLine() const						{ return cmdline; }
	bool saveFirst() const							{ if (section() == SECTCOMP) return true; else return false;}
	KShortcut shortcut() const						{ return cut; }
private:
	QString sect,mname,cmd,cmdline;
	KShortcut cut;
};

class KlatExecConfig
{
public:
	KlatExecConfig();
	~KlatExecConfig();
	void read(KConfig *cfg);
	void write(KConfig *cfg);
	bool gotoFirstEntry();
	bool gotoSectionEndEntry(const QString &sect);
	bool gotoNextEntry();
	bool gotoEntry(QString str);
	bool gotoEntry(int index);
	int position();
	QString section();
	QString menuName();
	QString command();
	QString commandLine();
	bool saveFirst();
	KShortcut shortcut();
	KlatExecMenuEntry entry();
	void insertAfterCurrent(const KlatExecMenuEntry &m);
	void deleteCurrent();
	void changeCurrent(const KlatExecMenuEntry &m);
private:
	QList<KlatExecMenuEntry> execEntries;
	QList<KlatExecMenuEntry>::iterator it;
};

#endif // KLATEXECCONFIG_H
